aboutsummaryrefslogtreecommitdiffstats
path: root/src/plugins/texteditor/fontsettingspage.h
diff options
context:
space:
mode:
authorTobias Hunger <tobias.hunger@nokia.com>2010-01-07 18:17:24 +0100
committerTobias Hunger <tobias.hunger@nokia.com>2010-01-07 18:17:24 +0100
commita6ad773722a758df46813afd7af42625a0f3e276 (patch)
tree8a74e3bb0fe819603e3ce5ed867116e75acc8d64 /src/plugins/texteditor/fontsettingspage.h
parent8bb87fcda497d09ac3ba39b38b9c229d02022b09 (diff)
Make method naming more consistent.
* Use id() for methods returning a string used to represent some type of object. * Use displayName() for strings that are meant to be user visible. * Quieten some warnings while touching the files anyway. * Move Factories to their products in the plugins where that was not done before. Reviewed-by: dt
Diffstat (limited to 'src/plugins/texteditor/fontsettingspage.h')
-rw-r--r--src/plugins/texteditor/fontsettingspage.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/plugins/texteditor/fontsettingspage.h b/src/plugins/texteditor/fontsettingspage.h
index 4e555c263b..caaa27b595 100644
--- a/src/plugins/texteditor/fontsettingspage.h
+++ b/src/plugins/texteditor/fontsettingspage.h
@@ -49,19 +49,19 @@ namespace Internal {
class FontSettingsPagePrivate;
} // namespace Internal
// GUI description of a format consisting of name (settings key)
// and trName to be displayed
class TEXTEDITOR_EXPORT FormatDescription
{
public:
- FormatDescription(const QString &name, const QString &trName,
+ FormatDescription(const QString &id, const QString &displayName,
const QColor &foreground = Qt::black);
- QString name() const
- { return m_name; }
+ QString id() const
+ { return m_id; }
- QString trName() const
- { return m_trName; }
+ QString displayName() const
+ { return m_displayName; }
QColor foreground() const;
QColor background() const;
@@ -70,8 +70,8 @@ public:
Format &format() { return m_format; }
private:
- QString m_name; // Name of the category
- QString m_trName; // Displayed name of the category
+ QString m_id; // Name of the category
+ QString m_displayName; // Displayed name of the category
Format m_format; // Default format
};
@@ -91,9 +91,9 @@ public:
~FontSettingsPage();
QString id() const;
- QString trName() const;
+ QString displayName() const;
QString category() const;
- QString trCategory() const;
+ QString displayCategory() const;
QWidget *createPage(QWidget *parent);
void apply();
@@ -49,19 +49,19 @@ namespace Internal {
class FontSettingsPagePrivate;
} // namespace Internal
-// GUI description of a format consisting of name (settings key)
-// and trName to be displayed
+// GUI description of a format consisting of id (settings key)
+// and displayName to be displayed
class TEXTEDITOR_EXPORT FormatDescription
{